#!/bin/sh
#/****************************************************************************/
#/* SVmcovm INSTALL SCRIPT                                                     */
#/*                                           Copyright FUJITSU LIMITED 2011 */
#/*                                                                          */
#/* $Name: SLINSVMCOVM-1_2_0-0 $                                                 */
#/****************************************************************************/
# Development date : Thu Nov 24 2011

#==============================================================================
# This is the script to install SVmco for Virtual Machine.
# Only root is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      More then 3 : Abnormal end
#==============================================================================

#--------------------------------------
# Function
#--------------------------------------

function _message_form() {
    echo "$*"
}

function message_out() {
    _message_form $*
}

function error() {
    _message_form $*
}

function log() {
    message_out $*
}

function Usage() {
    _message_form 'Usage:INSTALL.sh'
    popd >/dev/null
    exit 3
}

#--------------------------------------
# Define Environments
#--------------------------------------
export LANG=C
PATH=/bin:/sbin:/usr/bin:/usr/sbin

WORK_DIR=`dirname $0`
pushd $WORK_DIR >/dev/null
DRIVER_DIR=`pwd`
DRV_NAME=`basename $DRIVER_DIR`

BIN_DIR="/opt/fujitsu/SVmco/bin"
TOOLS="v2test_ei"

SVMCO_LIBDIR="/opt/fujitsu/SVmco/lib"
LIBCIM="libcimcClientXML.so.0.0.0"
LIBCIM_LN="libcimcClientXML.so"

#--------------------------------------
# Options.
#--------------------------------------
if ! [ $# -eq 0 ]; then
    Usage
fi

#--------------------------------------
# Confirmation of architecture.
#--------------------------------------
CPUTYPE=`uname -m`
if [ $CPUTYPE = "i686" ]; then
	:
elif [ $CPUTYPE = "i386" ]; then
	:
elif [ $CPUTYPE = "x86_64" ]; then
	:
else
    error "INSTALL.sh : This package can be installed only on x86 or Intel64."
    popd >/dev/null
    exit 4
fi

#--------------------------------------
# Check EUID
#--------------------------------------
if [ $EUID != 0 ]; then
    error "INSTALL.sh : only root can do that."
    popd >/dev/null
    exit 5
fi

#--------------------------------------
#  Install Start.
#--------------------------------------

#
#  Driver and tool RPM Package Install
#

RESULT=0
STATUS="notinstalled"
ACTION="installation"
RPM_OPT="-ivh"

DRVRPM=`find RPMS -name "SVmco*i[36]86.rpm" -print 2> /dev/null`
DRVRPM_COUNT=`echo "$DRVRPM" | wc -l`

if [ "$DRVRPM" = "" ] ; then
    error "RPM package was not found."
    RESULT=6
elif [ $DRVRPM_COUNT = 1 ] ; then
    RPMNAME=`basename $DRVRPM`
    PKGNAME=`rpm -qp "$DRVRPM"`
    RPM_DRVNAME=`rpm -qip ${DRVRPM} | awk '$1=="Name" {print $3}'`

    PKGNAME_OLD=`rpm -q $RPM_DRVNAME`
    if [ $? -eq 0 ]; then
        STATUS="installed"
        ACTION="update"
        RPM_OPT="-Fvh"
    fi

    RPM_PACKAGES="$DRVRPM"

    log "# rpm $RPM_OPT `echo $RPM_PACKAGES | sed -e "s/RPMS[/]//g"`"

    rpm $RPM_OPT $RPM_PACKAGES; ec=$?

    if [ "$ec" != "0" ]; then
        RESULT=8
        error "$RPMNAME ${ACTION} failed."
    else
        rpm -q $PKGNAME > /dev/null
        ec=$?
        if [ $ec -eq 0 ];then
            if [ "$ACTION" = "update" ]; then
                log "$RPMNAME is updated."
			else
                log "$RPMNAME is installed."

				pushd /opt/fujitsu/SVmco/sh/ > /dev/null

				./slsetup.sh install

				corros="Red Hat Enterprise Linux Server release 5"
				grep "${corros}" /etc/redhat-release > /dev/null 2>&1
				if [ $? -eq 0 ] ; then
					./setselinux.sh > /dev/null 2>&1
				fi

				popd >/dev/null
            fi
        else
            if [ "$STATUS" != "notinstalled" ]; then
                log "new package $DRV_NAME is already installed."
            fi
        fi
    fi
else
    error "Some old files exist in \"SVmco/RPMS\" directory."
    error "please retry installation after deleting old files."
    RESULT=7
fi

#--------------------------------------
#  Set cim client
#--------------------------------------
#if [ $RESULT -eq 0 ];then
# if [ $CPUTYPE = "x86_64" ] ; then
#     cp $BIN_DIR/arch/x86_64/$TOOLS $BIN_DIR
#     ln -s /usr/lib64/$LIBCIM $SVMCO_LIBDIR/$LIBCIM_LN > /dev/null
# else
#     cp $BIN_DIR/arch/x86/$TOOLS $BIN_DIR
#     ln -s /usr/lib/$LIBCIM $SVMCO_LIBDIR/$LIBCIM_LN > /dev/null
# fi
#fi

#--------------------------------------
#  Finish
#--------------------------------------

if [ $RESULT != 0 ];then
    error "$DRV_NAME $ACTION failed."
else
    log "$DRV_NAME $ACTION completed."
fi

popd >/dev/null
exit $RESULT
