#!/bin/sh
#/****************************************************************************/
#/* IPTABLES SETUP SCRIPT for PSA-MMB LAN                                    */
#/*                                          Copyright FUJITSU LTD 2011      */
#/*                                                                          */
#/* $Name: SLINSVMCOVM-1_0_0-0 $                                                     */
#/****************************************************************************/
# Development date : Mon DEC 12 2011
#==============================================================================
# This is the script to set the firewall for PSA-MMB LAN.
# Only FJSVpsa Installer is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

usage()
{
    echo "Invalid option"
    echo "Usage:"
    echo "For install: ./setiptables.sh install [Network interface name of PSA-MMB LAN]"
    echo "             ex) ./setiptables.sh install eth0"
    echo ""
    echo "For uninstall: setiptables.sh uninstall"
}

type=$1

case $type in
    'install')
	if [ $# -ne 2 ]
	    then
	    usage
	    exit 1
	fi
	;;
    'uninstall')
	if [ $# -ne 1 ]
	    then
	    usage
	    exit 1
	fi
esac

rule_num=6

#Check status
/sbin/service iptables status > /dev/null 2>&1

if [ $? -ne 0 ]
    then
case $type in
    'install')
	    echo ""
	    echo "#############################################################################################"
	    echo "# setiptables.sh couldn't set iptables setting. because iptables service has been stopped.  #"
	    echo "# Please set iptables setting by manual.                                                    #"
	    echo "# For more detail on how to set iptables setting, refer to the Installation Manual.         #"
	    echo "#############################################################################################"
	    echo ""
	    ;;
    'uninstall')
    	    echo ""
	    echo "##############################################################################################"
	    echo "# setiptables.sh couldn't delete iptables setting. because iptables service has been stopped.#"
	    echo "# Please delete iptables setting by manual.                                                  #"
	    echo "# For more detail on how to delete iptables setting, refer to the Installation Manual.       #"
	    echo "##############################################################################################"
	    echo ""
	    ;;
esac
    exit 0
fi

case $type in
    'install')

	IFNAME=$2
	ifconfig $IFNAME > /dev/null 2>&1

	if [ $? -ne 0 ]
	    then
	    echo "No such network interface $IFNAME." >&2
	    exit 1
	fi
	
	iptables -L PSA-MMB_LAN > /dev/null 2>&1
	if [ $? -eq 0 ]
	    then
	    echo "setiptables.sh has already set PSA-MMB_LAN."
	    exit 0
	fi

	iptables-save | grep ":PSA-MMB_LAN" > /dev/null 2>&1

	if [ $? -ne 0 ] ; then
	    iptables -N PSA-MMB_LAN
	fi
	
	count=1
	check1="PSA-MMB_LAN -i lo -j ACCEPT"
	check2="PSA-MMB_LAN -o lo -j ACCEPT"
	check3="PSA-MMB_LAN -o $IFNAME -p icmp -m icmp --icmp-type 8 -j ACCEPT"
	check4="PSA-MMB_LAN -i $IFNAME -p icmp -m icmp --icmp-type 0 -j ACCEPT"
	check5="PSA-MMB_LAN -i $IFNAME -p tcp -m tcp --sport 5000 -j ACCEPT"
	check6="PSA-MMB_LAN -o $IFNAME -p tcp -m tcp --dport 5000 -j ACCEPT"

	rule1="-i lo -j ACCEPT"
	rule2="-o lo -j ACCEPT"
	rule3="-p icmp --icmp-type echo-request -o $IFNAME -j ACCEPT"
	rule4="-p icmp --icmp-type echo-reply -i $IFNAME -j ACCEPT"
	rule5="-p tcp -i $IFNAME --sport 5000 -j ACCEPT"
	rule6="-p tcp -o $IFNAME --dport 5000 -j ACCEPT"

	

	while [ $count -le $rule_num ]
	  do
	  iptables-save | eval grep \""A \$check$count"\" > /dev/null 2>&1
	  Result=$?
	  if [ $Result -ne 0 ] ; then
	      eval iptables -I PSA-MMB_LAN $count \$rule$count
	  fi
	  count=`expr $count + 1`
	done
	
	/sbin/service iptables save > /dev/null 2>&1
	
	echo ""
	echo "############################################################################"
	echo "# Created the PSA-MMB_LAN chain on your firewall(iptables)                 #"
	echo "# For more detail on how to set firewall, refer to the Installation Manual.#"
	echo "############################################################################"
	echo ""
	exit 0
	
	;;
    'uninstall')
	
	iptables-save | grep ":PSA-MMB_LAN" > /dev/null 2>&1
	
	if [ $? -eq 0  ] ; then
	    
	    iptables -F PSA-MMB_LAN 
	    
	    count=`iptables-save | grep PSA-MMB_LAN | grep -v "^:" | wc -l`
	    
	    while [ $count -gt 0 ]
	      do
	      rule="`iptables-save | grep PSA-MMB_LAN | grep -v \"^:\" | head -n 1 | cut -d \" \" -f 2-`"
	      iptables -D $rule
	      count=`expr $count - 1`
	    done
	    
	    iptables -X PSA-MMB_LAN
	    
	    /sbin/service iptables save > /dev/null 2>&1
	fi

	exit 0
	;;
    *)
	usage
	exit 1
	;;
esac

echo "Firewall setting completed."
exit 0
